""" Package for the debug tree display suite (excluding GUI-specific implementations). """

from .base import DebugData, DebugDataFactory, package
